@@ -3,7 +3,7 @@
    Copyright (C) 2018 Ole Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 0.0.2 (2018-07-12)
+   Version: 0.0.4 (2018-07-14)
    Website: http://www.gingerblue.org/
  
  */
@@ -14,6 +14,13 @@
 #include <gtk/gtk.h>
 #include "gingerblue.h"
 
+gint
+gb_exit (void) {
+	gst_deinit();
+	gtk_main_quit();
+}
+
 gdouble gb_window_new_volume (GtkVolumeButton *volume, gchar *msg) {
-  g_print ("New volume: %0.2f\n", (gdouble) gtk_scale_button_get_value (GTK_SCALE_BUTTON (volume)));
+	g_print ("New volume: %0.2f\n", (gdouble) gtk_scale_button_get_value (GTK_SCALE_BUTTON (volume)));
+	return (gdouble) gtk_scale_button_get_value (GTK_SCALE_BUTTON (volume));
 }
