@@ -3,7 +3,7 @@
    Copyright (C) 2018 Ole Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 0.0.2 (2018-07-12)
+   Version: 0.0.4 (2018-07-14)
    Website: http://www.gingerblue.org/
  
  */
@@ -11,17 +11,25 @@
 #ifndef _GINGERBLUE_H_
 #define _GINGERBLUE_H_ 1
 
-typedef struct _GingerblueData {
-  GtkWidget *knob;  
-  gchar *line;
-  gint jack;
-  gchar *label;
-  gboolean lpf;
-  gboolean hpf;
-} GingerblueData;
+typedef struct _GingerblueData GingerblueData;
+
+struct _GingerblueData {
+	GtkWidget *knob;
+	gchar *line;
+	gint jack;
+	gchar *label;
+	gboolean lpf;
+	gboolean hpf;
+	gchar *version;
+	gchar *volume;
+	GingerblueData *next;
+	GingerblueData *prev;
+};
 
 /* gdouble gb_window_set_volume (GtkVolumeButton *volume, gpointer value); */
 gdouble gb_window_new_volume (GtkVolumeButton *volume, gchar *msg);
 /* gdouble gb_window_get_volume (GtkVolumeButton *volume, gpointer value); */
 
+gint gb_exit (void);
+
 #endif /* _GINGERBLUE_H_ */
